---
layout: assignment
published: true

title: Website/App Accessibility UARS (Individual)
description: Learn to assess website/app accessibility using a variety of technologies
code: hw3

assigned: October 11th, 2023
due: October 16th, 2023 (2 day grace period, October 18th, 2023)
   
revised: October 10, 2023

---
* TOC
{: toc}

# Overview
The goal of this homework is to learn about basics of website accessibility and how to assess. In part 1, you: Learn how to use automated tools (and their limitations); Learn how to address the limitations of automated tools using accessibility tools; In part 2, you: Learn how to write up an assessment and prioritize what problems to fix; Practice identifying paths to fixing problems. You will also have the opportunity to practice UI image description. 

## Competencies
This homework may contribute to your competency grade on 
- Can apply web/app accessibility rules to understand conformance and identify violations on:
  1. whether content is perceivable
  2. whether content is operable 
  3. whether content is understandable
  4. whether content is robust
  <!-- - 5 the meaning of conformance -->
- Can use an accessibility checker to assess whether a web page or app is accessible
- Can use an accessibility technology to find web page or app accessibility problems that are not found with an automated accessibility checker
- Demonstrate familiarity with a range of accessibility technologies (at least 2)
- Can articulate paths to addressing accessibility problems
- Image description
- Your participation grade, as a percentage of:
 - completeness (are all the required parts present)
 - consistency: are you applying the skills you've learned so far consistently as relevant?

## Length & Difficulty
Students in the past have reported that taken together, part 1 (assigned Oct 11) and part 2 of this assignment (assigned Oct 18) require a median of 20 hours (mode=6). A challenge that multiple students faced is summarizing the WCAG guidelines in their own words. Please be sure to do so, *or* to quote and reference WCAG guidelines according to our [course policy on academic conduct]({{site.baseurl}}/academic-conduct.html). Some things that students have told us about this assignment:
- It helps to use the [UAR template](webegs/UAR_Template.doc) when filling out the UARS.
- It was very motivating to do this for a real client

Here is a [sample set of UARs](webegs/DDUARS.docx) that a prior student who completed this assignment has kindly shared with us for you to look at. 

# Details
Your goal is to generate a range of UARs (Usability Aspect Reports) documenting accessibility concerns (and perhaps successes) with a website or app. You will use [W3C guidelines](https://www.w3.org/WAI/standards-guidelines/) for the site or app you are assessing. 

The most relevant are probably [WCAG
2.1](https://www.w3.org/WAI/standards-guidelines/wcag/glance/) and
[How WCAG 2.0 Applies to
Mobile](https://www.w3.org/TR/mobile-accessibility-mapping/) (even
websites may be used in mobile settings). If you are working on a
mobile app, you should also review this PDF (specifically page
9): [Epidemiology as a Framework for Large-Scale Mobile Application
Accessibility
Assessment](https://xiaoyizhang.me/assets/Paper/ASSETS_2017_Epidemiology.pdf).

Optional readings:
 - the Anatomy of the YouDescribe welcome page section of the [tutorial](https://youdescribe.org/support/tutorial)


## 0. Look over your assigned website and select 3 tasks
You will be assigned to one of eight websites that were submitted by external organizations for review. Please see Canvas for your specific assignment group. Note that this is *not* a group project, we are asking you to individually work on your assigned website this week. You will join forces *next* week to write a report. 

You will need to select what aspect of this site to test, you should have at least 3 different well defined tasks that you test. For example, for DSHS, you might select tasks such as something from the "How Do I" column; contacting support, and finding information about something in the Disability support section.

{% details List of Websites %}

- [DSHS.wa.gov](https://www.dshs.wa.gov/) -- Our community uses this site for public health services and disability support information. 
- King County Library Systems
  - [KCLS app](https://apps.apple.com/us/app/kcls/id746221889) (requires an iPhone). No specific task was provided, but they said "Assessing this App will benefit patrons with disability who use this App to access KCLS resource" 
  - [Libby](https://apps.apple.com/us/app/libby-by-overdrive-labs/id1076402606?utm_campaign=libby&utm_medium=lightning_banner&utm_source=lightning). Again, no task is provided, just that it is "important for accessing library services".
- [HuskyAdapt](https://depts.washington.edu/adaptuw/) -- This is a UW student group. They say "A lot of individuals with disabilities and adults that work with individuals with disabilities access our website." 
- [Mason County Elections](https://masoncountywaelections.gov/) -- "It provides information on services available to help people with disabilities vote."
- Thurston County Government
   - [Thurston County Auditor's Office](https://www.thurstoncountywa.gov/departments/auditor) --  "The county just relaunched our web content management system. In addition to our other public facing services, we also conduct election in Thurston County. We would like to especially know if our website works for all users prior to the 2024 election cycle." Focus on the Thurston County Auditor's Office section only. 
   - [Thurston County Board of County Commissioners](https://www.thurstoncountywa.gov/departments/board-county-commissioners) -- "This is where constituents go to get information on the activities/decisions/meetings/etc. of the Board of County Commissioners" 
- Snohomish County Auditor's Office [Snohomish County Auditor's Office](https://snohomishcountywa.gov/176/Auditor) -- "We have recently received feedback from the Arc of Snohomish County that many voters with disabilities do not know about the options available to them for voting. We would like to be able to direct more people to our website, but have heard that there are barriers to navigating and accessing needed information. We want to embark on updating our website, but leadership isn't 100% convinced yet that this is necessary. This assessment would help to further make our case that an update is essential to improving accessibility of our services." They particularly want a focus on the information architecture; and it is OK to divide up the sub pages among all students assigned to this. Here is a suggested division:
  - Animal Services
  - Elections
  - Licensing
  - Recording 

{% enddetails %}

## 1. Collect Data on  accessibility problems using an automated accessibility checker
For each of these steps, you will record data about what you find so that you can complete the write up at the end.

You should run the website and/or app through an accessibility checker. The WebAim accessibility checker, [WAVE](https://wave.webaim.org/), is a great choice for many sites. However, if the site requires that you log in, you may need an alternative. A great choice is the [Axe Chrome plugin](https://chrome.google.com/webstore/detail/axe-devtools-web-accessib/lhdoppojpmngadmnindnejefpokejbdd?hl=en-US). 

To install the Accessibility Scanner on android, search for it in the
Play Store and install it on your device or emulator. The installation
process will be the same for a physical phone or the emulator equipped
with the Play Store. Follow the instructions on the [Getting started
with Google Accessibility
Scanner](https://support.google.com/accessibility/android/answer/6376570?hl=en&ref_topic=6376582)
page to get the scanner working on your device. Another option is to install the Android Accessibility Suite which contains both the Accessibility Scanner and TalkBack if it has not been installed before.

For iOS, you should install the Accessibility Inspector, which is freely available through the App Store. More details on [testing for accessibility in iOS.](https://developer.apple.com/library/archive/documentation/Accessibility/Conceptual/AccessibilityMacOSX/OSXAXTestingApps.html)

## 2. Collect Data on accessibility problems using TWO DIFFERENT accessibility technologies
Use *multiple approaches*, including at a minimum  **a screen reader**, and an other AT to assess the accessibility of the website and/or app, and your ability to complete the assigned task using
accessibility tools. The second AT you choose should provide different information than what a screen reader would. For example, using switch control or voice input are good second choices. However, using the tab key to navigate the website as the second AT is **NOT** considered for competency.
You may also use other accessibility tools if 

Here are some resources that may help you in gaining comfort with these accessibility technologies 
- [Setting up a screen reader testing environment](https://www.sarasoueidan.com/blog/testing-environment-setup/)
- [Zoomtext and other magnification in use](https://www.youtube.com/watch?v=4ZRVDgeMpXc) and [Setting up windows for zooming](https://www.youtube.com/watch?v=TQhUCnMhDZE)
- [Screen reading intro](https://axesslab.com/what-is-a-screen-reader/)
- Switch control intro: [Switch Control overview](https://www.youtube.com/watch?v=GQKEE9nI1lk)
- Advanced voice based input: [voice programming](https://www.youtube.com/watch?v=YKuRkGkf5HU)

## 3.  Record the data in a *Usability Aspect Report*
Record each group of similar issues you find using this [Usability Aspect Report Template](webegs/UAR_Template.doc). Here is a [sample set of UARs](webegs/DDUARS.docx) that a prior student has kindly shared with us for you to look at. Make sure that your UARs are accessible. Be sure to include problems that you found with an automated tool *and* things that you could only find using manual testing with a screen reader or other accessibility technology.

Some key things to make note of: 
- **Good or Bad Feature** *If your website as very accessible* you may include UARS for particularly good features 
- **Source** including *your initials*; *the type of AT used*; and a unique ID. For example, JM-SR-3 (which means, approximately, Jennifer Mankoff Screen Reader UAR # 3).
- **Name/Brief Description** Provide a very brief name/summary
- **Evidence** Specify the guideline violated and provide a screen shot with ALT text or other evidence of the violation. 
- **Explanation** Explain why this is a problem (or good aspect).
- **Severity** Rank severity (with 4 being catastrophe) 
- **Justification** Justify your ranking in terms of *frequency*, *impact* and *persistence*
- **Relationship to other problems** If this is related to/caused by/causes other problems you record, you can give their *source* number here

# Turnin

1. Submit your UARS (an accessible document that is not a PDF) as an attachment to the appropriate discussion as specified in Canvas. In addition to your UARs, this document should :
 - Specify the tasks you were testing in your submission. 
- An answer to this question: What are some examples of problems you could only identify with manual testing using an accessibility technology (instead of an automated tester)?
2. Also upload this document as a file upload on canvas.
