---
layout: default
title: Schedule
description: Class schedule and links to lectures, readings and assignments
---

* TOC
{:toc}

{: .module} 
# Module 1: Accessibility Basics 

{: .week}
# Week 1 (9/27 - 9/29): Introduction to Disability & Accessibility

{% details Learning Goals and Class Plan %} 
## Learning Goals
- What is Disability?
- What is Accessibility?
- What are Accessibility Technologies?

## Lecture Plan
**Wednesday Slides** {% include slide.html title="Introduction to Course" loc="introduction.html" %}

**Thursday Section** Discussion and demos of access technologies

**Friday Slides** {% include slide.html title="Accessibility" loc="accessibility.html" %}

## Homework 

{: .homework} Required Reading and Reflection
: 

- **Required**
   -  Read about [Disability Dongles](https://www.vox.com/first-person/2019/4/30/18523006/disabled-wheelchair-access-ramps-stair-climbing)  and  [**Respond**]({{site.discussion}}/3515126)
- **If you want to dig deeper**
   - Defining Article [Disability Dongles](https://blog.castac.org/2022/04/disability-dongle/) by Liz Jackson 
   
{: .homework} [AT Around Us](assignments/finding-accessibility.html) Assigned: Find Accessibility Technologies
: 

{% enddetails %}

{: .week}
# Week 2 (10/2 - 10/6): Accessible Documents & Disability Justice

{% details Learning Goals and Class Plan %} 

## Learning Goals

We will start understanding how to make documents accessible
- How to present accessibly
- Get comfortable with basic image  description (images, people)
- Plain Language 
And study disability justice
- Understand models for disability-centered design
- What is Disability Justice 

## Lecture Plan
**Monday Slides** {% include slide.html title="Accessible Presentations and Presenting Accessibly" loc="presenting-accessibly.html" %}

**Monday/Wednesday Slides** {% include slide.html title="Introduction to Disability Justice" loc="disability-justice.html" %}

**Wednesday Slides** {% include slide.html title="Introduction to Plain Language" loc="plain-language.html" %}

**Thursday: Section**: Practice with Plain Language

**Friday: AT Around Us Presentations**
   - Zoom only day (rather than having three different physical rooms)
   - We will break up into three groups, each with a different zoom link so that we can record your presentations
   - Look for an Ed announcement on this

## Homework

{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required**
  -  The [10 principles of disability justice](https://static1.squarespace.com/static/5bed3674f8370ad8c02efd9a/t/5f1f0783916d8a179c46126d/1595869064521/10_Principles_of_DJ-2ndEd.pdf) and  [Respond]({{site.discussion}}/3543980)
  - [Plain language writing](https://www.forbes.com/sites/andrewpulrang/2020/10/22/plain-language-writing---an-essential-part-of-accessibility/?sh=2c70bd7e7935) and  [Respond]({{site.discussion}}/3543980)
- **If you want to dig deeper**
  - [Design, Disability and Knowing the 'Other'](https://dl.acm.org/doi/fullHtml/10.1145/3290605.3300528#:~:text=WHAT%20IS%20EMPATHY%3F-,The%20Promise%20of%20Empathy%3A%20Design%2C%20Disability,%2C%20and%20Knowing%20the%20'Other'&text=This%20paper%20examines%20the%20promise,order%20to%20inform%20technology%20development.) 
  - [Plain language](https://pudding.cool/2022/02/plain/) 

{: .homework} [Disability Justice Homework](assignments/disabilityjustice.html) Assigned: Pick an access topic and analyze it from a disability justice perspective.
: 


{% enddetails %}

{: .week}
# Week 3 (10/9-10/13): Guidelines and Assessment

{% details Learning Goals and Class Plan%} 
## Learning Goals

- What are the current accessibility standards
- How do we use automated tools to assess accessibility
- How can we use accessibility technology to assess accessibility
- Get comfortable using existing freely available accessibility technology to support assessment
- More advanced accessibility techniques
    - Differences between Image description, Diagram description and UI description
    - Video description & Captioning
    - Math, Tables & other elements (including custom interactors)

## Lecture Plan
**Monday Slides** {% include slide.html title="Accessibility Testing" loc="testing.html" %}

**Wednesday** 
- {: .prepare} Come Prepared
: Come to class with an image, diagram, or other graphic you want to describe
- **Slides** {% include slide.html title="Accessibility Standards & Media Accessibility" loc="assessment.html" %}

**Thursday Section**: Practice with Accessibility Assessment 

**Friday Slides** {% include slide.html title="More Accessibility Standards" loc="assessment2.html" %}

## Homework
{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required**
  - Accessibility Testing: Read [The Importance of Manual Accessibility Testing](https://www.smashingmagazine.com/2018/09/importance-manual-accessibility-testing/) and [**Respond**]({{site.discussion}}/3580191)
  - Read about [creating accessible images and diagrams](https://dis.acm.org/2023/creating-accessible-figures-and-tables/) and [**Respond**](https://edstem.org/us/courses/41400/discussion/3580191)
       - Find a non-text content on the web that does not have ALT text (something other than a photograph)
       - [Post](https://edstem.org/us/courses/31170/discussion/2394641) a description of [the leftmost GUI](img/assessment/gui.png) 
  - Audio Description: Read [What is audio description?](https://adp.acb.org/articles/adprocess.html) (from [The Audio Description Project](https://www.acb.org/adp/ad.html)) and [**Respond**]({{site.discussion}}/3580191)
- **If you want to dig deeper**
   - Read about [Switches](https://axesslab.com/switches/)
   - Try out the [Image ALT Text Tutorial](https://webaim.org/techniques/alttext/) 
   - Watch: [Rescribe: Authoring and Automatically Editing Audio Descriptions](https://www.youtube.com/watch?v=jmyPmT5T0PY)
   - Read about [Making numbers accessible](https://www.tpgi.com/making-numbers-in-web-content-accessible/)n


{: .homework} [Website Testing Homework](assignments/website.html) Assigned: Assess a website or app and generate UARS for it
: 

{% enddetails %}

{: .week}
# Week 4 (10/16-10/20): Building & Remediating Accessible Interfaces

{% details Learning Goals & Plan %} 
## Learning Goals
- How accessibility works under the hood
- More on navigation and its impact 
- What are the trade offs between different tools?

## Lecture Plan
**Monday Slides** {% include slide.html title="How to build for accessibility" loc="best-practices.html" %}

**Wednesday Slides** {% include slide.html title="Implementing Accessibility" loc="access-trees.html" %}
Maybe a hands on exercise. Also discuss Aria

**Thursday Section** Group work on Report

**Friday Slides** {% include slide.html title="Comparing Automated Testing and Manual Testing" loc="comparing-approaches.html" %}

## Homework
{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required**

   - Read: About how [web semantics are conveyed to screen readers](https://alistapart.com/article/semantics-to-screen-readers/)   and [**Respond**]({{site.discussion}}/3636487) 
- **If you want to dig deeper**
   - Read: [Accessibility in Software Practice: A Practitioner’s Perspective](https://dl.acm.org/doi/abs/10.1145/3503508) 
   - Read: [Is your web page accessible? A comparative study of methods for assessing web page accessibility for the blind](https://dl.acm.org/doi/10.1145/1054972.1054979) and [**Respond**]({{site.discussion}})
   - Read: [Comparison of different methods for accessibility testing](https://sol.sbc.org.br/journals/index.php/jis/article/view/1778/1848) Mateus etal, 2021 
   - Watch: [Google Video on Practical Web Accessibility](https://www.youtube.com/watch?v=x18vEEfpK3g) — this video provides a great overview of the Web and how to make web content accessible. Highly recommended as a supplement to what we will cover in class.
   - Watch: [Latte: Use-Case and Assistive-Service Driven Automated Accessibility Testing Framework for Android](https://www.youtube.com/watch?v=Z84jeO0UZFE) and read [Lies, Damned Lies, Overlays, and Widgets](https://www.linkedin.com/pulse/lies-damned-overlays-widgets-timothy-springer/)
   - Read: [Semantics for Eye tracking](https://dl.acm.org/doi/pdf/10.1145/3338844)

{: .homework} [Website Report](assignments/website-report.html) Assigned: Write a group report about your assessment
: 

{% enddetails %}

{: .week}
# Week 5 (10/23 - 10/27): Accessible Need-Finding and Evaluation

{% details Learning Goals & Plan %} 
## Learning Goals
- How to assess whether a technology is accessible; and whether an accessibility technology is useful and usable, in an inclusive fashion.
- How do you make sure your *product is accessible* to people with disabilities
   1. Data Equity and implicit bias
   2. Beyond automated assessment: Accessible Summative Studies
   3. Importance of Intersectionality
- How do you make sure your *accessibility technology is valued* by people with disabilities
   - What are potential data sources for assessing value
   - Collaboration Versus Paternalism
   - Overly narrow views of disability: Multiple disabled people & multiply disabled people

## Lecture Plan
**Monday Slides** {% include slide.html title="Guest Lecture: Avery Mack: Assessing Accessibility" loc="evaluation.html" %}

**Wednesday** Conversation with Jaipreet Virdi 
- Dr. Jaipreet Virdi will be lecturing on 10/24 at 6:30pm on "The Disabled Gaze: Rethinking the Past, Remaking the Future". 
Please contact the instructors if you would like to attend -- we have 25 tickets to give out
- In addition, she will join us in class for a conversation about disability and technology and the disabled gaze. This is a chance for you to bring questions about her and her work. 

**Friday Slides** {% include slide.html title="Best of ASSETS" loc="best-of-assets2023.html" %}

## Homework
{: .homework} Required Reading and Reflection (for Wednesday)
: - Attend [**Jaipreet Virdi's talk**](https://www.washington.edu/lectures/events/the-disabled-gaze-rethinking-the-past-remaking-the-future/) at 6:30pm on Tuesday if you're able (ask us for tickets) *or* read [Q&A with Jaipret Virdi](https://disabilityvisibilityproject.com/2020/08/10/qa-with-jaipreet-virdi/) by Alice Wong on the [Disability Project website](https://disabilityvisibilityproject.com).
  
{% details Jaipreet Virdi Bio and Talk Abstract%}

Jaipreet Virdi, Associate Professor, Department of History at the University of Delaware,  is a scholar activist. Her first book, Hearing Happiness: Deafness Cures in History raises pivotal questions about deafness in American society and the endless quest for a cure. Her writing has appeared in Slate, The Washington Post, The Atlantic, Psyche, The Wellcome Collection, and the New Internationalist. She is on Twitter as @jaivirdi 

How do disabled people use their technologies to draw attention to, rather than hide, their disability? The disabled gaze is an autonomous claiming of identity that rejects typical perceptions of disability as objectifying or exploitative. It offers a way to examines how disabled people, past and present, asserted themselves—through art, for instance—or challenged medical assumptions about their bodies. 

What happens when we center the disabled gaze in our creations of the future? In this talk, Dr. Jaipreet Virdi asks us to consider how being disabled changes the ways people view the world and the things they create. Through these perspectives, she invites alternative approaches for remaking crip worlds, one in which disabled people, and the disabled gaze, are centered first and foremost. 

The lecture will be accompanied by an ASL interpreter and will include CART captioning.
{% enddetails %}

 
- Read [Blurring the Boundaries Between Assistive Tech and Companionship](https://www.forbes.com/sites/gusalexiou/2021/01/26/amazon-alexa---blurring-the-boundaries-between-assistive-tech-and-companionship/?sh=3bf833b75e7b) and [**Respond**]({{site.discussion}}/3694599)

- **If you want to dig deeper**
  - Read [Anticipate and Adjust](https://dl.acm.org/doi/abs/10.1145/3491102.3501882)
  - Read [Accessibility came by accident](https://dl.acm.org/doi/pdf/10.1145/3173574.3174033?casa_token=T1I2RwihIjsAAAAA:QEm3SjurdlcW7oX_1LadxaglZ7oneBX-XLIjMCHbof3gu_IFpDW2OO5tqxZfLIps-94Qik9y5wNw8Q)
  - Read [How to do something good in the disability community if you're not disabled](https://www.forbes.com/sites/andrewpulrang/2020/12/16/how-to-do-something-good-in-the-disability-community-if-youre-not-disabled/?sh=21ef25c97d7f)

{: .homework} **Continued**  [Website Report](assignments/website-report.html) 
: 
{% enddetails %}


{: .module} 
# Module 2: Post GUI Accessibility 

{: .week}
# Week 6 (10/30 - 11/3): Fabrication
{% details Learning Goals & Plan  %} 
## Learning Goals
- Work with laser cutting to make accessible technology
- Learn about fabrication tools and techniques

## Lecture Plan
**Monday Slides** {% include slide.html title="Introduction to 3D Printing and Physical Computing" loc="3dprinting.html" %}

**Wednesday**: Making a Laser Cut Book Opener 
Work in class on this

**Thursday Section**: 
Finish making laser cuttable designs and print

**Friday** Discussion of implementation assignment (technology selection & task selection) & possible discussion of accessibility implementation in the real world with guests (may also be Monady). 
- Check in to make sure you have a plan and it is do-able

## Homework
{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required: Respond to the Reading Questions and Preparation Requirements.**
   - Read [Lasercutting with Tinkercad](https://www.tinkercad.com/blog/laser-cutting-with-Tinkercad) and join our (Tinkercard Classroom)[https://www.tinkercad.com/joinclass/IEPJ5JFZ3] and complete the tutorial in our [Laser Cut Accessibility Aid](https://www.tinkercad.com/classrooms/gVpVydMts11/activities/e98dyTpqqmK) activity.
   - Read [Empowering individuals with do-it-yourself assistive technology](https://drive.google.com/open?id=17M_-NY35P0wnXTD1kacD33Tt43lqwMsu&usp=drive_fs) and respond to the reading question on Ed.
- **If you want to go deeper**
   - [Consumer-Grade Fabrication and Its Potential to Revolutionize Accessibility](https://dl.acm.org/doi/10.1145/3339824), CACM 2019 
  - [Fairness issues in AI Systems that augment sensory abilities](https://arxiv.org/pdf/1908.07333.pdf) 

{: .homework} **Assigned:**  [Technology Review](assignments/technology-review.html)
: 
{% enddetails %}


{: .draft}
# Everything after this is draft

{% details draft content %}

{: .week}
# Week 7 (11/6 - 11/10): Accessible Visualizations & AR/VR
{% details Learning Goals and Class Plan %} 

Bias in Machine Learning
    - What is Machine Learning (ML)? 
    - What are the components of ML?
    - How do we collect data? Who do we collect the data from?
    - Is the data "good"?
    - How do we minimize disability bias?

Accessible Data Visualizations
    - What are the commonly-used techniques to make data visualizations accessible?
    - What are the pros and cons of these techniques?
    - What are some of the nuances in making data visualizations accessible?

Learn about how to make AR/VR interfaces and games accessible


**Monday Slides** {% include slide.html title="Data Equity" loc="bias-in-machine-learning.html" %}

{: .homework} Required Reading and Reflection (for Wednesday)
: 

- **Required: Respond to the Reading Questions and Preparation Requirements.**
  - [Areas of Strategic Visibility: Disability Bias in Biometrics](https://arxiv.org/abs/2208.04712  - [Explaining Explanations: An Approach to Evaluating Interpretability of Machine Learning](https://www.cs.purdue.edu/homes/bb/nit/Lalana-Explainations%20of%20IAS.pdf)
  - [Increasing Data Equity in Accessibility](https://arxiv.org/abs/2210.01902) 
- **If you want to go deeper**
  - [A systematic literature review of handheld augmented reality solutions for people with disabilities](https://www.mdpi.com/1424-8220/22/20/7719)
  - [Understanding Screen-Reader Users’ Experiences with Online Data Visualizations](https://athersharif.me/documents/assets-2021-understanding-sru-experiences-online-data-viz.pdf) [**Respond**](TBD)
  - [Data Representation in Accessibility Data Sets: A Meta-analysis](https://arxiv.org/abs/2207.08037) [**Respond**](TBD)
  - [The Future of Urban Accessibility for People with Disabilities: Data Collection, Analytic, Policy, and Tools](https://dl.acm.org/doi/fullHtml/10.1145/3517428.3550402)
  - [Rich Screen Reader Experiences for Accessible Data Visualization](https://arxiv.org/pdf/2205.04917.pdf)
  - [VoxLens: Making Online Data Visualizations Accessible With an Interactive JavaScript Plug-In](https://athersharif.me/documents/chi-2022-voxlens.pdf)

{% enddetails %}


{% details Wednesday 11/1: AR/VR Accessibility %} 

**Slides** {% include slide.html title="AR/VR Accessibility" loc="arvr.html" %}

**Friday Slides** {% include slide.html title="Designing for and with people with disabilities" loc="designing.html" %}


{: .homework} [Technology Review](assignments/technology-implementation.html) Assigned: Make something (post-gui) more accessible
: 

{% enddetails %}
 
{% details Thursday: Section %} 
Practice with making data accessible

{% enddetails %}
## Friday 11/10: HOLIDAY
{: .holiday}



{: .week}

# Module 3: Everything Everywhere All at Once

{: .week}

{: .homework} [Final Project Proposal](assignments/project-proposals.html) Assigned: Prepare your final project proposal (individual)
: 

# Week 8 (11/13-11/17): Chronic Illness  & Sustainability
{% details Learning Goals %}
- How to assess whether a technology is accessible; and whether an accessibility technology is useful and usable, in an inclusive fashion.
- How do you make sure your *product is accessible* to people with disabilities
   1. Data Equity and implicit bias
   2. Beyond automated assessment: Accessible Summative Studies
   3. Importance of Intersectionality
- How do you make sure your *accessibility technology is valued* by people with disabilities
   - What are potential data sources for assessing value
   - Collaboration Versus Paternalism
   - Overly narrow views of disability: Multiple disabled people & multiply disabled people
{% enddetails %}


{% details Monday 11/13: Group Formation %}

In class exercise to form final project groups

{: .homework} Required Reading and Reflection (for Wednesday)
: 
- **Required: Respond to the Reading Questions and Preparation Requirements on Ed**. There is only one Ed post you need to make this week in response to either or both assigned readings. [Please post your response in this Ed thread]({site.discussion}/2649283)
  - [Difficulty Vs Accessibility](https://www.youtube.com/watch?v=sPehhHZvKE8&list=PLVEo4bPIUOskja9pfpqceY8qDrykFdubf&index=18)
  - [My Disability Is Dynamic](https://medium.com/age-of-awareness/my-disability-is-dynamic-bc2a619fcc1)
- **If you want to dig deeper**
  - [Considerations for HCI accessibility practices with chronically ill people](https://dl.acm.org/doi/abs/10.1145/3517428.3544803)

{% enddetails %}

{% details Wednesday 11/15: Chronic Illness and Accessibility %}

**Slides** TBD

{: .homework} [Group Project Checkpoint](assignments/project-checkpoint.html) Assigned: Group Project Checkpoint
: 

{: .homework} [Final Project Handin](assignments/project-final.html) 
: 

{% enddetails %}
 
{% details Thursday: Section %}
Work in groups on final projects

{% enddetails %}

{% details Friday 11/17: Sustainability  %}

**Slides** {% include slide.html title="Sustainability" loc="sustainability.html" %}

{% enddetails %}

{: .week}
# Week 9 (11/20-11/24): Group  Checkpoints (Full Group Required)

Sign up for a meeting slot *with your whole group* (details to be announced; slots will overlap class but also extend beyond class hours)

## Thursday 11/23 and Friday 11/24: HOLIDAY
{: .holiday}

{: .week}
# Week 10 (12/4--12/8): 1:1 Project Meetings / TBD
{% details Learning Goals: STILL TBD %}
TBD
{% enddetails %}


{% details Monday: Richard Ladner guest lecture %}
{% enddetails %}

{: .week}
# Finals week: Final presentations -- 12/12, late afternoon (around 2:30-4ish)

{: .lecture} Final project presentations
: 



# Unused Reading and Ideas
{% details some additional readings and slides to possibly use %}
- Physical computing slides
- [Crippin' Jim Crow](https://drive.google.com/file/d/1QaRu4T3aax6jg73quHKgpfwJe3nQ4PEv/view?usp=share_link) 
- [Traumatic Brain Injury: A Guide for Criminal Justice Professionals](https://www.brainline.org/article/traumatic-brain-injury-guide-criminal-justice-professionals)
- [Disabling Incarceration: Connecting Disability to Divergent Confinements in the USA](https://journals.sagepub.com/doi/pdf/10.1177/0896920511430864?casa_token=4JF2JifTBBwAAAAA:FOPw2ZwZDMbyKoRLloJIhzc4ZQTf25dnTt1NnvR6yaD-S8OfE96U-Un8QLA3_sOw7EGBk3ro8hUv)
- [A systematic literature review of handheld augmented reality solutions for people with disabilities](https://www.mdpi.com/1424-8220/22/20/7719) 
- [7 benefits of AR and VR for People with Disabilities](https://arpost.co/2022/02/09/7-benefits-ar-vr-for-people-with-disability/) (a bit ableist)
- [Living Disability Theory: Reflections on Research, Access and Design](https://make4all.org/wp-content/uploads/2020/09/hoffmann-living-disability-theory.pdf)
- [Disability Studies as a source of critical inquiry...](https://make4all.org/wp-content/uploads/2019/10/MankoffAssets2010.pdf)
- [Vital coronavirus is failing the blind and visually impaired](https://www.vice.com/en/article/4ag9wb/vital-coronavirus-information-is-failing-the-blind-and-visually-impaired)
- [Blurring the Boundaries Between Assistive Tech and Companionship](https://www.forbes.com/sites/gusalexiou/2021/01/26/amazon-alexa---blurring-the-boundaries-between-assistive-tech-and-companionship/?sh=2821499375e7) (a little too salesy)
{% enddetails %}

{% details slides not in use %}
**Slides** {% include slide.html title="Assessing Accessibility" loc="physical-computing.html" %}
{% enddetails %}


{% details topics not covered %}
- Video conferencing
-  Large gatherings (virtual or hybrid)
- Online text based support groups
- Social networks such as twitter or facebook 
- Crowdsourcing )
{% enddetails %}




{% enddetails %}
